# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`network`](#network): Manage network devices
* [`network::eth::bridge_packages`](#networkethbridge_packages): Include the required bridge packages
* [`network::global`](#networkglobal): This sets up the global options in /etc/sysconfig/network  See /usr/share/doc/initscripts-<version>/sysconfig.txt for details of each option.
* [`network::service`](#networkservice): Contains all supported network management services
* [`network::service::legacy`](#networkservicelegacy): Restarts the network using a wrapper script that delays execution until *after* the Puppet agent run is finished.  This ensures that network 
* [`network::service::network_manager`](#networkservicenetwork_manager): Restarts the network using a wrapper script that delays execution until *after* the Puppet agent run is finished.  This ensures that network 

### Defined types

* [`network::eth`](#networketh): This sets up a particular ethernet device config file.  See /usr/share/doc/initscripts-<version>/sysconfig.txt for details of each option.  F
* [`network::route`](#networkroute): Add a static route to an interface.  See /usr/share/doc/initscripts-<version>/sysconfig.txt for details of each option.  Note: At this time m

### Data types

* [`Network::BondMode`](#networkbondmode): Valid bond modes for network interfaces
* [`Network::Eth::BootProto`](#networkethbootproto): Valid ethernet boot protocols
* [`Network::TransmitPolicy`](#networktransmitpolicy): Valid network transmit policies
* [`Network::VlanType`](#networkvlantype): taken from http://lxr.free-electrons.com/source/net/8021q/vlan.c?v=2.6.32#L310

## Classes

### <a name="network"></a>`network`

Manage network devices

#### Parameters

The following parameters are available in the `network` class:

* [`auto_restart`](#auto_restart)

##### <a name="auto_restart"></a>`auto_restart`

Data type: `Boolean`

Restart the network if necessary due to a configuration change.

Default value: ``true``

### <a name="networkethbridge_packages"></a>`network::eth::bridge_packages`

Include the required bridge packages

#### Parameters

The following parameters are available in the `network::eth::bridge_packages` class:

* [`package_ensure`](#package_ensure)

##### <a name="package_ensure"></a>`package_ensure`

Data type: `Simplib::PackageEnsure`

The state to which the required packages should be set

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

### <a name="networkglobal"></a>`network::global`

This sets up the global options in /etc/sysconfig/network

See /usr/share/doc/initscripts-<version>/sysconfig.txt for details of
each option.

#### Parameters

The following parameters are available in the `network::global` class:

* [`gateway`](#gateway)
* [`gatewaydev`](#gatewaydev)
* [`hostname`](#hostname)
* [`ipv6_autoconf`](#ipv6_autoconf)
* [`ipv6_autotunnel`](#ipv6_autotunnel)
* [`ipv6_defaultdev`](#ipv6_defaultdev)
* [`ipv6_defaultgw`](#ipv6_defaultgw)
* [`ipv6_router`](#ipv6_router)
* [`ipv6forwarding`](#ipv6forwarding)
* [`network`](#network)
* [`networkdelay`](#networkdelay)
* [`networking`](#networking)
* [`networking_ipv6`](#networking_ipv6)
* [`nisdomain`](#nisdomain)
* [`nozeroconf`](#nozeroconf)
* [`peerdns`](#peerdns)
* [`vlan`](#vlan)
* [`auto_restart`](#auto_restart)
* [`persistent_dhclient`](#persistent_dhclient)

##### <a name="gateway"></a>`gateway`

Data type: `Optional[Simplib::IP]`



Default value: ``undef``

##### <a name="gatewaydev"></a>`gatewaydev`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="hostname"></a>`hostname`

Data type: `Simplib::Hostname`



Default value: `$facts['fqdn']`

##### <a name="ipv6_autoconf"></a>`ipv6_autoconf`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ipv6_autotunnel"></a>`ipv6_autotunnel`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ipv6_defaultdev"></a>`ipv6_defaultdev`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ipv6_defaultgw"></a>`ipv6_defaultgw`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ipv6_router"></a>`ipv6_router`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ipv6forwarding"></a>`ipv6forwarding`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="network"></a>`network`

Data type: `Optional[Simplib::IP]`



Default value: ``undef``

##### <a name="networkdelay"></a>`networkdelay`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="networking"></a>`networking`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="networking_ipv6"></a>`networking_ipv6`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="nisdomain"></a>`nisdomain`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="nozeroconf"></a>`nozeroconf`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="peerdns"></a>`peerdns`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="vlan"></a>`vlan`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="auto_restart"></a>`auto_restart`

Data type: `Optional[Boolean]`

Restart the network if necessary due to a configuration change.

Default value: `$network::auto_restart`

##### <a name="persistent_dhclient"></a>`persistent_dhclient`

Data type: `Optional[Boolean]`



Default value: ``undef``

### <a name="networkservice"></a>`network::service`

Contains all supported network management services

#### Parameters

The following parameters are available in the `network::service` class:

* [`manage_legacy`](#manage_legacy)
* [`manage_network_manager`](#manage_network_manager)

##### <a name="manage_legacy"></a>`manage_legacy`

Data type: `Boolean`

Enable management of the legacy 'network' service

Default value: ``true``

##### <a name="manage_network_manager"></a>`manage_network_manager`

Data type: `Boolean`

Enable management of the NetworkManager service

* Defaults to the running active state of NetworkManager on the target system

Default value: `pick(fact('simplib__networkmanager.enabled'), false)`

### <a name="networkservicelegacy"></a>`network::service::legacy`

Restarts the network using a wrapper script that delays execution until
*after* the Puppet agent run is finished.

This ensures that network changes aren't applied during a Puppet agent run
and potentially disrupt its other configurations and report (unless
explicitly configured otherwise in specific `network::eth` declarations).

### <a name="networkservicenetwork_manager"></a>`network::service::network_manager`

Restarts the network using a wrapper script that delays execution until
*after* the Puppet agent run is finished.

This ensures that network changes aren't applied during a Puppet agent run
and potentially disrupt its other configurations and report (unless
explicitly configured otherwise in specific `network::eth` declarations).

## Defined types

### <a name="networketh"></a>`network::eth`

This sets up a particular ethernet device config file.

See /usr/share/doc/initscripts-<version>/sysconfig.txt for details of
each option.

For bonding options see /usr/share/doc/iputils-20020927/README.bonding.
Particularly, section "3.2 Configuration with Initscripts Support" and
"2. Bonding Driver Options".

DEVICE is taken from $name
HWADDR is pulled from facter if possible.
ONBOOT is aliased to ONPARENT for alias devices

FIXME: This does require that you include 'network::redhat' to get the network
service defined.

The following 3 options are passed as dhclientargs.

#### Parameters

The following parameters are available in the `network::eth` defined type:

* [`name`](#name)
* [`auto_discover_mac`](#auto_discover_mac)
* [`bonding`](#bonding)
* [`arp`](#arp)
* [`bond_arp_interval`](#bond_arp_interval)
* [`bond_arp_ip_target`](#bond_arp_ip_target)
* [`bond_downdelay`](#bond_downdelay)
* [`bond_lacp_rate`](#bond_lacp_rate)
* [`bond_max_bonds`](#bond_max_bonds)
* [`bond_miimon`](#bond_miimon)
* [`bond_mode`](#bond_mode)
* [`bond_primary`](#bond_primary)
* [`bond_updelay`](#bond_updelay)
* [`bond_use_carrier`](#bond_use_carrier)
* [`bond_xmit_hash_policy`](#bond_xmit_hash_policy)
* [`bootproto`](#bootproto)
* [`bridge`](#bridge)
* [`broadcast`](#broadcast)
* [`delay`](#delay)
* [`dhclient_ignore_gateway`](#dhclient_ignore_gateway)
* [`dhclient_request_option_list`](#dhclient_request_option_list)
* [`dhclient_timeout`](#dhclient_timeout)
* [`dhclient_vendor_class_identifier`](#dhclient_vendor_class_identifier)
* [`dhcpclass`](#dhcpclass)
* [`dhcp_hostname`](#dhcp_hostname)
* [`dhcprelease`](#dhcprelease)
* [`dns1`](#dns1)
* [`dns2`](#dns2)
* [`ethtool_opts`](#ethtool_opts)
* [`ensure`](#ensure)
* [`reorder_hdr`](#reorder_hdr)
* [`gateway`](#gateway)
* [`hotplug`](#hotplug)
* [`hwaddr`](#hwaddr)
* [`ipaddr`](#ipaddr)
* [`ipv6_autoconf`](#ipv6_autoconf)
* [`ipv6_control_radvd`](#ipv6_control_radvd)
* [`ipv6_mtu`](#ipv6_mtu)
* [`ipv6_privacy`](#ipv6_privacy)
* [`ipv6_radvd_pidfile`](#ipv6_radvd_pidfile)
* [`ipv6_radvd_trigger_action`](#ipv6_radvd_trigger_action)
* [`ipv6_router`](#ipv6_router)
* [`ipv6addr`](#ipv6addr)
* [`ipv6addr_secondaries`](#ipv6addr_secondaries)
* [`ipv6init`](#ipv6init)
* [`ipv6to4_ipv4addr`](#ipv6to4_ipv4addr)
* [`ipv6to4_mtu`](#ipv6to4_mtu)
* [`ipv6to4_relay`](#ipv6to4_relay)
* [`ipv6to4_routing`](#ipv6to4_routing)
* [`ipv6to4init`](#ipv6to4init)
* [`isalias`](#isalias)
* [`linkdelay`](#linkdelay)
* [`macaddr`](#macaddr)
* [`master`](#master)
* [`metric`](#metric)
* [`mtu`](#mtu)
* [`net_type`](#net_type)
* [`netmask`](#netmask)
* [`network`](#network)
* [`nm_controlled`](#nm_controlled)
* [`nozeroconf`](#nozeroconf)
* [`onboot`](#onboot)
* [`peerdns`](#peerdns)
* [`physdev`](#physdev)
* [`persistent_dhclient`](#persistent_dhclient)
* [`slave`](#slave)
* [`srcaddr`](#srcaddr)
* [`userctl`](#userctl)
* [`vlan`](#vlan)
* [`vlan_name_type`](#vlan_name_type)
* [`window`](#window)
* [`auto_restart`](#auto_restart)

##### <a name="name"></a>`name`

DEVICE is taken from this variable.

##### <a name="auto_discover_mac"></a>`auto_discover_mac`

Data type: `Boolean`

Determine whether or not the system should try and auto-discover a MAC
address for the interface specified.

Default value: ``true``

##### <a name="bonding"></a>`bonding`

Data type: `Boolean`

This variable does not translate into an init script option. If you set
this to true instead of false any hardware address auto-discovery will be
ignored. Otherwise, the interface will attempt to auto-discover the
interface. If you explicitly set hwaddr or macaddr, then this will be
ignored.

Default value: ``false``

##### <a name="arp"></a>`arp`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="bond_arp_interval"></a>`bond_arp_interval`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="bond_arp_ip_target"></a>`bond_arp_ip_target`

Data type: `Optional[Simplib::IP]`



Default value: ``undef``

##### <a name="bond_downdelay"></a>`bond_downdelay`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="bond_lacp_rate"></a>`bond_lacp_rate`

Data type: `Optional[Integer[0,1]]`



Default value: ``undef``

##### <a name="bond_max_bonds"></a>`bond_max_bonds`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="bond_miimon"></a>`bond_miimon`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="bond_mode"></a>`bond_mode`

Data type: `Optional[Network::BondMode]`



Default value: ``undef``

##### <a name="bond_primary"></a>`bond_primary`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="bond_updelay"></a>`bond_updelay`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="bond_use_carrier"></a>`bond_use_carrier`

Data type: `Optional[Integer[0,1]]`



Default value: ``undef``

##### <a name="bond_xmit_hash_policy"></a>`bond_xmit_hash_policy`

Data type: `Optional[Network::TransmitPolicy]`



Default value: ``undef``

##### <a name="bootproto"></a>`bootproto`

Data type: `Network::Eth::BootProto`



Default value: `'dhcp'`

##### <a name="bridge"></a>`bridge`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="broadcast"></a>`broadcast`

Data type: `Optional[Simplib::IP]`



Default value: ``undef``

##### <a name="delay"></a>`delay`

Data type: `Optional[Integer]`

If hosting VMs, set delay to 0.

Default value: ``undef``

##### <a name="dhclient_ignore_gateway"></a>`dhclient_ignore_gateway`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="dhclient_request_option_list"></a>`dhclient_request_option_list`

Data type: `Optional[Array[String]]`



Default value: ``undef``

##### <a name="dhclient_timeout"></a>`dhclient_timeout`

Data type: `Integer`



Default value: `10080`

##### <a name="dhclient_vendor_class_identifier"></a>`dhclient_vendor_class_identifier`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="dhcpclass"></a>`dhcpclass`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="dhcp_hostname"></a>`dhcp_hostname`

Data type: `Optional[Simplib::Hostname]`



Default value: ``undef``

##### <a name="dhcprelease"></a>`dhcprelease`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="dns1"></a>`dns1`

Data type: `Optional[Simplib::Host]`



Default value: ``undef``

##### <a name="dns2"></a>`dns2`

Data type: `Optional[Simplib::Host]`



Default value: ``undef``

##### <a name="ethtool_opts"></a>`ethtool_opts`

Data type: `Optional[Array[String[1]]]`



Default value: ``undef``

##### <a name="ensure"></a>`ensure`

Data type: `Enum['absent','present']`



Default value: `'present'`

##### <a name="reorder_hdr"></a>`reorder_hdr`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="gateway"></a>`gateway`

Data type: `Optional[Simplib::IP]`



Default value: ``undef``

##### <a name="hotplug"></a>`hotplug`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="hwaddr"></a>`hwaddr`

Data type: `Optional[Simplib::Macaddress]`

If you set this, you have the following options:
  1) Leave Blank -> Auto-detect (default)
  2) Set to something with ':' -> Set to MAC address (if valid)
  3) Set to anything else -> Leave unset and add a comment

Default value: ``undef``

##### <a name="ipaddr"></a>`ipaddr`

Data type: `Optional[Simplib::IP]`



Default value: ``undef``

##### <a name="ipv6_autoconf"></a>`ipv6_autoconf`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ipv6_control_radvd"></a>`ipv6_control_radvd`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ipv6_mtu"></a>`ipv6_mtu`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="ipv6_privacy"></a>`ipv6_privacy`

Data type: `String[1]`



Default value: `'rfc3041'`

##### <a name="ipv6_radvd_pidfile"></a>`ipv6_radvd_pidfile`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ipv6_radvd_trigger_action"></a>`ipv6_radvd_trigger_action`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ipv6_router"></a>`ipv6_router`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ipv6addr"></a>`ipv6addr`

Data type: `Optional[Simplib::IP::V6]`



Default value: ``undef``

##### <a name="ipv6addr_secondaries"></a>`ipv6addr_secondaries`

Data type: `Optional[Array[Simplib::IP::V6]]`



Default value: ``undef``

##### <a name="ipv6init"></a>`ipv6init`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ipv6to4_ipv4addr"></a>`ipv6to4_ipv4addr`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ipv6to4_mtu"></a>`ipv6to4_mtu`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="ipv6to4_relay"></a>`ipv6to4_relay`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ipv6to4_routing"></a>`ipv6to4_routing`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ipv6to4init"></a>`ipv6to4init`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="isalias"></a>`isalias`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="linkdelay"></a>`linkdelay`

Data type: `Optional[Integer[1]]`



Default value: ``undef``

##### <a name="macaddr"></a>`macaddr`

Data type: `Optional[Simplib::Macaddress]`

If you set this variable, it will override any setting for $hwaddr!

Default value: ``undef``

##### <a name="master"></a>`master`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="metric"></a>`metric`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="mtu"></a>`mtu`

Data type: `Optional[Integer[1]]`



Default value: ``undef``

##### <a name="net_type"></a>`net_type`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="netmask"></a>`netmask`

Data type: `Optional[Simplib::IP]`



Default value: ``undef``

##### <a name="network"></a>`network`

Data type: `Optional[Simplib::IP]`



Default value: ``undef``

##### <a name="nm_controlled"></a>`nm_controlled`

Data type: `Boolean`

**EXPERIMENTAL** feature to mark an interface as controlled by
NetworkManager. If set, the code attempts a best-effort case to enable the
interface and control it via the NetworkManager tools.

Default value: `pick(fact('simplib__networkmanager.enabled'), false)`

##### <a name="nozeroconf"></a>`nozeroconf`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="onboot"></a>`onboot`

Data type: `Optional[Boolean]`



Default value: ``true``

##### <a name="peerdns"></a>`peerdns`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="physdev"></a>`physdev`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="persistent_dhclient"></a>`persistent_dhclient`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="slave"></a>`slave`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="srcaddr"></a>`srcaddr`

Data type: `Optional[Simplib::IP]`



Default value: ``undef``

##### <a name="userctl"></a>`userctl`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="vlan"></a>`vlan`

Data type: `Boolean`



Default value: ``false``

##### <a name="vlan_name_type"></a>`vlan_name_type`

Data type: `Optional[Network::VlanType]`



Default value: ``undef``

##### <a name="window"></a>`window`

Data type: `Optional[Integer[1]]`



Default value: ``undef``

##### <a name="auto_restart"></a>`auto_restart`

Data type: `Optional[Boolean]`

Restart the network if necessary due to a configuration change.

* Will use the value from the main `network` class if not set.

Default value: ``undef``

### <a name="networkroute"></a>`network::route`

Add a static route to an interface.

See /usr/share/doc/initscripts-<version>/sysconfig.txt for details of
each option.

Note: At this time multiple static routes can only be added by injecting
      newlines into the cidr_netmask variable. See the following as an example:

      cidr_netmask => "192.168.1.0/24 via 192.168.0.1\n192.168.2.0/24"

#### Parameters

The following parameters are available in the `network::route` defined type:

* [`interface`](#interface)
* [`cidr_netmask`](#cidr_netmask)
* [`next_hop`](#next_hop)
* [`auto_restart`](#auto_restart)

##### <a name="interface"></a>`interface`

Data type: `String`



##### <a name="cidr_netmask"></a>`cidr_netmask`

Data type: `String`



##### <a name="next_hop"></a>`next_hop`

Data type: `Simplib::IP`



##### <a name="auto_restart"></a>`auto_restart`

Data type: `Boolean`

Restart the network if necessary due to a configuration change.

Default value: ``true``

## Data types

### <a name="networkbondmode"></a>`Network::BondMode`

Valid bond modes for network interfaces

Alias of

```puppet
Variant[Integer[0,6], Enum[
    'balance-rr',
    'active-backup',
    'balance-xor',
    'broadcast',
    '802.3ad',
    'balance-tlb',
    'balance-alb'
  ]]
```

### <a name="networkethbootproto"></a>`Network::Eth::BootProto`

Valid ethernet boot protocols

Alias of

```puppet
Enum['none', 'static', 'bootp', 'dhcp']
```

### <a name="networktransmitpolicy"></a>`Network::TransmitPolicy`

Valid network transmit policies

Alias of

```puppet
Enum['layer2', 'layer2+3', 'layer3+4']
```

### <a name="networkvlantype"></a>`Network::VlanType`

taken from http://lxr.free-electrons.com/source/net/8021q/vlan.c?v=2.6.32#L310

Alias of

```puppet
Enum['VLAN_NAME_TYPE_RAW_PLUS_VID', 'VLAN_NAME_TYPE_PLUS_VID_NO_PAD', 'VLAN_NAME_TYPE_RAW_PLUS_VID_NO_PAD', 'VLAN_NAME_TYPE_PLUS_VID']
```

